==> zio-aws-sesv2_3-5.17.128.1-sources.jar: zio/aws/sesv2/model/CreateDedicatedIpPoolRequest.scala <==
package zio.aws.sesv2.model
import zio.aws.sesv2.model.primitives.PoolName
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class CreateDedicatedIpPoolRequest(
    poolName: PoolName,
    tags: Option[Iterable[zio.aws.sesv2.model.Tag]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sesv2.model.CreateDedicatedIpPoolRequest = {
    import CreateDedicatedIpPoolRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sesv2.model.CreateDedicatedIpPoolRequest
      .builder()
      .poolName(PoolName.unwrap(poolName): java.lang.String)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.sesv2.model.CreateDedicatedIpPoolRequest.ReadOnly =
    zio.aws.sesv2.model.CreateDedicatedIpPoolRequest.wrap(buildAwsValue())
}
object CreateDedicatedIpPoolRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sesv2.model.CreateDedicatedIpPoolRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sesv2.model.CreateDedicatedIpPoolRequest =
      zio.aws.sesv2.model.CreateDedicatedIpPoolRequest(
        poolName,
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def poolName: PoolName
    def tags: Option[List[zio.aws.sesv2.model.Tag.ReadOnly]]
    def getPoolName: ZIO[Any, Nothing, PoolName] = ZIO.succeed(poolName)
    def getTags: ZIO[Any, AwsError, List[zio.aws.sesv2.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sesv2.model.CreateDedicatedIpPoolRequest
  ) extends zio.aws.sesv2.model.CreateDedicatedIpPoolRequest.ReadOnly {
    override val poolName: PoolName =
      zio.aws.sesv2.model.primitives.PoolName(impl.poolName())
    override val tags: Option[List[zio.aws.sesv2.model.Tag.ReadOnly]] = scala
      .Option(impl.tags())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.sesv2.model.Tag.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.sesv2.model.CreateDedicatedIpPoolRequest
  ): zio.aws.sesv2.model.CreateDedicatedIpPoolRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-sesv2_3-5.17.195.3-sources.jar: zio/aws/sesv2/model/CreateDedicatedIpPoolRequest.scala <==
package zio.aws.sesv2.model
import zio.aws.sesv2.model.primitives.PoolName
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class CreateDedicatedIpPoolRequest(
    poolName: PoolName,
    tags: Optional[Iterable[zio.aws.sesv2.model.Tag]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sesv2.model.CreateDedicatedIpPoolRequest = {
    import CreateDedicatedIpPoolRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sesv2.model.CreateDedicatedIpPoolRequest
      .builder()
      .poolName(PoolName.unwrap(poolName): java.lang.String)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.sesv2.model.CreateDedicatedIpPoolRequest.ReadOnly =
    zio.aws.sesv2.model.CreateDedicatedIpPoolRequest.wrap(buildAwsValue())
}
object CreateDedicatedIpPoolRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sesv2.model.CreateDedicatedIpPoolRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sesv2.model.CreateDedicatedIpPoolRequest =
      zio.aws.sesv2.model.CreateDedicatedIpPoolRequest(
        poolName,
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def poolName: PoolName
    def tags: Optional[List[zio.aws.sesv2.model.Tag.ReadOnly]]
    def getPoolName: ZIO[Any, Nothing, PoolName] = ZIO.succeed(poolName)
    def getTags: ZIO[Any, AwsError, List[zio.aws.sesv2.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sesv2.model.CreateDedicatedIpPoolRequest
  ) extends zio.aws.sesv2.model.CreateDedicatedIpPoolRequest.ReadOnly {
    override val poolName: PoolName =
      zio.aws.sesv2.model.primitives.PoolName(impl.poolName())
    override val tags: Optional[List[zio.aws.sesv2.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.sesv2.model.Tag.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.sesv2.model.CreateDedicatedIpPoolRequest
  ): zio.aws.sesv2.model.CreateDedicatedIpPoolRequest.ReadOnly = new Wrapper(
    impl
  )
}
